@@ -4,24 +4,22 @@
 import errno
 import logging
 import os
+import glob
 import shutil
 from collections import OrderedDict
 from typing import IO, Any, Dict, List, MutableMapping, Optional
 from urllib.parse import urlparse
 import portalocker
 import logging
-import os
 import shutil
 from typing import Callable, Optional
 from urllib import request
-
+import cv2 as cv
 
 
 __all__ = ["PathManager", "get_cache_dir", "file_lock"]
 
 
-
-
 def download(
     url: str, dir: str, *, filename: Optional[str] = None, progress: bool = True
 ):
@@ -55,6 +53,7 @@ def download(
         logger.info("Downloading from {} ...".format(url))
         if progress:
             import tqdm
+
             def hook(t: tqdm.tqdm) -> Callable[[int, int, Optional[int]], None]:
                 last_b = [0]
 
@@ -308,7 +307,8 @@ class NativePathHandler(PathHandler):
         """
         if os.path.exists(dst_path) and not overwrite:
             logger = logging.getLogger(__name__)
-            logger.error("Destination file {} already exists.".format(dst_path))
+            logger.error(
+                "Destination file {} already exists.".format(dst_path))
             return False
 
         try:
@@ -565,3 +565,63 @@ class PathManager:
 
 
 PathManager.register_handler(HTTPURLHandler())
+
+
+class SourceIter:
+
+    def __init__(self, src):
+        self.src = src
+        self.srcs = []
+        self._index = 0
+        self.video_mode = False
+        self.cap = None
+
+    def __len__(self):
+        return len(self.src)
+
+    def __next__(self):
+        if self.video_mode:
+            assert self.cap is not None, 'video mode on but cap is None. video open failed.'
+            ret, frame = self.cap.read()
+            if not ret:
+                print('Seems iteration done. bye~')
+                exit(0)
+            return frame
+        else:
+            if self._index < len(self.srcs):
+                p = self.srcs[self._index]
+                self._index += 1
+                return p
+            else:
+                print('Seems iteration done. bye~')
+                exit(0)
+                # raise StopIteration
+
+
+class ImageSourceIter(SourceIter):
+
+    def __init__(self, src):
+        super(ImageSourceIter, self).__init__(src)
+        
+        self._index_sources()
+        assert len(self.srcs) > 0, 'srcs indexed empty: {}'.format(self.srcs)
+    
+    def _is_video(self, p):
+        if str(p).endswith('.mp4') or str(p).endswith('.avi'):
+            return True
+        else:
+            return False
+
+    def _index_sources(self):
+        if os.path.isfile(self.src) and self._is_video(self.src):
+            self.video_mode = True
+            self.cap = cv.VideoCapture(self.src)
+            self.srcs = [self.src]
+        elif os.path.isfile(self.src):
+            self.srcs = [self.src]
+        elif os.path.isdir(self.src):
+            for ext in ('*.bmp', '*.png', '*.jpg'):
+                self.srcs.extend(glob.glob(os.path.join(self.src, ext)))
+            # print(self.srcs)
+        else:
+            TypeError('{} must be dir or file'.format(self.src))
