@@ -34,14 +34,14 @@ import numpy as np
 from .common import get_unique_color_by_id, get_unique_color_by_id2, get_unique_color_by_id_with_dataset
 from .det import draw_one_bbox
 from PIL import Image
-from .get_dataset_color_map import create_cityscapes_label_colormap, create_ade20k_label_colormap, create_mapillary_vistas_label_colormap, create_pascal_label_colormap
-
+from .get_dataset_color_map import *
 
 ALL_COLORS_MAP = {
     "cityscapes": create_cityscapes_label_colormap(),
     "mapillary": create_mapillary_vistas_label_colormap(),
     "ade20k": create_ade20k_label_colormap(),
     "voc": create_pascal_label_colormap(),
+    "coco": create_coco_stuff_colormap(),
 }
 
 
@@ -200,7 +200,7 @@ def draw_masks_maskrcnn_v2(image, boxes, scores, labels, masks, human_label_list
 
 
 # more fast mask drawing here
-def vis_bitmasks(img, bitmasks, fill_mask=True, return_combined=True, thickness=1):
+def vis_bitmasks(img, bitmasks, fill_mask=True, return_combined=True, thickness=1, draw_contours=True):
     """
     visualize bitmasks on image
     """
@@ -208,7 +208,7 @@ def vis_bitmasks(img, bitmasks, fill_mask=True, return_combined=True, thickness=
     if isinstance(bitmasks, torch.Tensor):
         bitmasks = bitmasks.cpu().numpy()
 
-    res_m = np.zeros_like(img)
+    res_m = np.zeros_like(img).astype(np.uint8)
     assert isinstance(bitmasks, np.ndarray), 'bitmasks must be numpy array'
     bitmasks = bitmasks.astype(np.uint8)
     for i, m in enumerate(bitmasks):
@@ -221,8 +221,9 @@ def vis_bitmasks(img, bitmasks, fill_mask=True, return_combined=True, thickness=
             if fill_mask:
                 cv2.drawContours(res_m, cts, -1,  color=c,
                                  thickness=-1, lineType=cv2.LINE_AA)
-                cv2.drawContours(img, cts, -1,  color=c,
-                                 thickness=1, lineType=cv2.LINE_AA)
+                if draw_contours:
+                    cv2.drawContours(img, cts, -1,  color=c,
+                                 thickness=thickness, lineType=cv2.LINE_AA)
             else:
                 cv2.drawContours(res_m, cts, -1,  color=c,
                                  thickness=thickness, lineType=cv2.LINE_AA)
@@ -240,7 +241,7 @@ def vis_bitmasks(img, bitmasks, fill_mask=True, return_combined=True, thickness=
         return img
 
 
-def vis_bitmasks_with_classes(img, classes, bitmasks, fill_mask=True, return_combined=True, thickness=1):
+def vis_bitmasks_with_classes(img, classes, bitmasks, force_colors=None, mask_border_color=None, alpha=0.85, fill_mask=True, return_combined=True, thickness=1):
     """
     visualize bitmasks on image
     """
@@ -256,14 +257,17 @@ def vis_bitmasks_with_classes(img, classes, bitmasks, fill_mask=True, return_com
             m = cv2.resize(m, (img.shape[1], img.shape[0]))
         cts, _ = cv2.findContours(m, cv2.RETR_TREE, cv2.CHAIN_APPROX_NONE)
         # inssue this is a unique color
-        cid = classes[i]
-        c = get_unique_color_by_id2(cid)
+        cid = int(classes[i])
+        if force_colors:
+            c = force_colors[cid]
+        else:
+            c = get_unique_color_by_id2(cid)
         if return_combined:
             if fill_mask:
                 cv2.drawContours(res_m, cts, -1,  color=c,
                                  thickness=-1, lineType=cv2.LINE_AA)
-                cv2.drawContours(img, cts, -1,  color=c,
-                                 thickness=1, lineType=cv2.LINE_AA)
+                cv2.drawContours(img, cts, -1,  color=mask_border_color if mask_border_color else c,
+                                 thickness=thickness, lineType=cv2.LINE_8)
             else:
                 cv2.drawContours(res_m, cts, -1,  color=c,
                                  thickness=thickness, lineType=cv2.LINE_AA)
@@ -275,7 +279,7 @@ def vis_bitmasks_with_classes(img, classes, bitmasks, fill_mask=True, return_com
                 cv2.drawContours(img, cts, -1,  color=c,
                                  thickness=thickness, lineType=cv2.LINE_AA)
     if return_combined:
-        img = cv2.addWeighted(img, 0.9, res_m, 0.6, 0.8)
+        img = cv2.addWeighted(img, 0.9, res_m, alpha, 0.5)
         return img
     else:
         return img
@@ -297,6 +301,8 @@ def label2color_mask(cls_id_mask, max_classes=90, override_id_clr_map=None, colo
         else:
             colors = np.array([override_id_clr_map[i % len(
                 override_id_clr_map)] for i in range(max_classes)])
+    if len(colors) < max_classes:
+        colors = np.append(colors, ALL_COLORS_MAP['cityscapes'][:max_classes-len(colors)], axis=0)
 
     s = cls_id_mask.shape
     if len(s) > 1:
